package com.vetti.hotake.service;

import java.util.List;
import com.vetti.hotake.domain.HotakeRolesApplyOperRecord;

/**
 * 岗位申请操作信息Service接口
 * 
 * @author wangxiangshun
 * @date 2026-01-18
 */
public interface IHotakeRolesApplyOperRecordService 
{
    /**
     * 查询岗位申请操作信息
     * 
     * @param id 岗位申请操作信息主键
     * @return 岗位申请操作信息
     */
    public HotakeRolesApplyOperRecord selectHotakeRolesApplyOperRecordById(Long id);

    /**
     * 查询岗位申请操作信息列表
     * 
     * @param hotakeRolesApplyOperRecord 岗位申请操作信息
     * @return 岗位申请操作信息集合
     */
    public List<HotakeRolesApplyOperRecord> selectHotakeRolesApplyOperRecordList(HotakeRolesApplyOperRecord hotakeRolesApplyOperRecord);

    /**
     * 新增岗位申请操作信息
     * 
     * @param hotakeRolesApplyOperRecord 岗位申请操作信息
     * @return 结果
     */
    public int insertHotakeRolesApplyOperRecord(HotakeRolesApplyOperRecord hotakeRolesApplyOperRecord);

    /**
     * 修改岗位申请操作信息
     * 
     * @param hotakeRolesApplyOperRecord 岗位申请操作信息
     * @return 结果
     */
    public int updateHotakeRolesApplyOperRecord(HotakeRolesApplyOperRecord hotakeRolesApplyOperRecord);

    /**
     * 批量删除岗位申请操作信息
     * 
     * @param ids 需要删除的岗位申请操作信息主键集合
     * @return 结果
     */
    public int deleteHotakeRolesApplyOperRecordByIds(Long[] ids);

    /**
     * 删除岗位申请操作信息信息
     * 
     * @param id 岗位申请操作信息主键
     * @return 结果
     */
    public int deleteHotakeRolesApplyOperRecordById(Long id);

    /**
     * 批量新增岗位申请操作信息
     *
     * @param hotakeRolesApplyOperRecordList 岗位申请操作信息列表
     * @return 结果
     */
    public int batchInsertHotakeRolesApplyOperRecord(List<HotakeRolesApplyOperRecord> hotakeRolesApplyOperRecordList);

}
